<template>
  <!-- 搜索工作栏 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="标题" prop="snapshotConfigName">
        <el-input
          v-model="queryParams.snapshotConfigName"
          placeholder="请输入图表名称"
          clearable
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="模型ID" prop="snapshotConfigCode">
        <el-input
          v-model="queryParams.snapshotConfigCode"
          placeholder="请输入模型ID"
          clearable
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px"/>
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px"/>
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>

      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table
      v-loading="loading"
      :data="list"
      row-key="id"
    >
      <el-table-column prop="title" label="标题"/>
      <el-table-column prop="modelId" label="模型ID"/>
      <el-table-column prop="scheduleObj" label="调整对象"/>
      <el-table-column label="操作" align="center" width="200px">
        <template #default="scope">
          <div class="flex items-center justify-center">
            <el-button
              link
              type="primary"
              @click="openForm('update', scope.row.id)"
            >
              编辑
            </el-button>
            <el-button
              link
              type="primary"
              @click="openSnapshotConfigDet(scope.row.id)"
            >
              参数
            </el-button>
            <el-button link type="danger" @click="handleDelete(scope.row.id)">
              删除
            </el-button>
          </div>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      v-model:limit="queryParams.limit"
      v-model:page="queryParams.page"
      :total="total"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <SnapshotConfigForm ref="formRef" @success="getList" />

  <!-- 分组列表 -->
  <SnapshotConfigDet ref="SnapshotConfigDetRef" />

</template>
<script lang="ts" setup>
import {dateFormatter} from '@/utils/formatTime'
import * as SnapshotConfigApi from '@/api/model/sche/suggest/snapshotConfig'
import SnapshotConfigForm from './configForm.vue'
import SnapshotConfigDet from './det/index.vue'


defineOptions({name: 'SnapshotConfig'})

const message = useMessage() // 消息弹窗
const {t} = useI18n() // 国际化

const loading = ref(true) // 列表的加载中
const total = ref(0) // 列表的总页数
const list = ref([]) // 字典表格数据
const queryParams = reactive({
  page: 1,
  limit: 10,
  modelId: '',
  snapshotConfigCode: ''
})
const queryFormRef = ref() // 搜索的表单

const getList = async () => {
  loading.value = true
  try {
    const data = await SnapshotConfigApi.getPage(queryParams)
    list.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

/** 搜索按钮操作 */
const handleQuery = () => {
  getList()
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value.resetFields()
  handleQuery()
}

/** 添加/修改操作 */
const formRef = ref()
const openForm = (type: string, id?: string) => {
  formRef.value.open(type, id)
}

/** 删除按钮操作 */
const handleDelete = async (id: string) => {
  try {
    // 删除的二次确认
    await message.delConfirm()
    // 发起删除
    await SnapshotConfigApi.del(id)
    message.success(t('common.delSuccess'))
    // 刷新列表
    await getList()
  } catch {
  }
}

/** List操作 */
const SnapshotConfigDetRef = ref()
const openSnapshotConfigDet = (id?: string) => {
  SnapshotConfigDetRef.value.open(id)
}

/** 初始化 **/
onMounted(async () => {
  await getList()
})
</script>
